@@ -24,8 +24,8 @@ def find_period(x: pd.Series, method_period: str = "median") -> float:
     Estimates the period of a time series
 
     Args:
-         x (pandas.Series): Time series
-         method_period (str): Method to estimate period
+         x: Time series
+         method_period: Method to estimate period
             can be 'median' or 'min' of the difference of timestamps
     Returns:
          float: period in nanoseconds
@@ -52,10 +52,10 @@ def calculate_completeness(x: pd.Series, time_start: pd.Timestamp, time_end: pd.
     Calculates the completeness score of an input time series for a certain date range
 
     Args:
-         x (pandas.Series): Time series
-         time_start (pd.Timestamp): start time of date range
-         time_end (pd.Timestamp): end time of date range
-         period (float): timeseries period in ns
+         x: Time series
+         time_start: start time of date range
+         time_end: end time of date range
+         period: timeseries period in ns
 
     Returns:
          float: completeness score
@@ -96,17 +96,17 @@ def completeness_score(
     score is below the medium completeness ratio.
 
     Args:
-         x (pandas.Series): Time series
-         cutoff_good (float): Good cutoff
+         x: Time series
+         cutoff_good: Good cutoff
              Value between 0 and 1. A completeness score above this cutoff value
              indicates good data completeness. Defaults to 0.80.
-         cutoff_med (float): Medium cutoff
+         cutoff_med: Medium cutoff
              Value between 0 and 1 and lower than the good data completeness
              cutoff. A completeness score above this cutoff and below the good
              completeness cutoff indicates medium data completeness. Data
              with a completeness score below it are categorised as poor data
              completeness. Defaults to 0.60.
-         method_period (str): Method
+         method_period: Method
              Name of the method used to estimate the period of the time series, can be 'median' or 'min'.
              Default is 'median'
     Returns:
