@@ -71,7 +71,7 @@ class UncertaintyDataQualityScoreAnalyser(DataQualityScoreAnalyser):
         return score
 
     @staticmethod
-    def _plot(series, estimated_truth, events, score):
+    def _plot(series, estimated_truth, events, score):  # pragma: no cover
         from matplotlib import pyplot as plt
 
         _, ax1 = plt.subplots()
