@@ -27,17 +27,17 @@ def ssd_cpd(
     considered a steady or transient region.
 
     Args:
-        data (pandas.Series): Time series.
+        data: Time series.
 
-        min_distance (int, optional): Minimum distance.
+        min_distance: Minimum distance.
             Specifies the minimum point wise distance for each segment that will be considered in the Change
             Point Detection algorithm.
 
-        var_threshold (float, optional): Variance threshold.
+        var_threshold: Variance threshold.
             Specifies the variance threshold. If the normalized variance calculated for a given segment is greater than
             the threshold, the segment will be labeled as transient (value = 0).
 
-        slope_threshold (float, optional): Slope threshold.
+        slope_threshold: Slope threshold.
             Specifies the slope threshold. If the slope of a line fitted to the data of a given segment is greater than
             10 to the power of the threshold value, the segment will be labeled as transient (value = 0).
 
@@ -121,17 +121,17 @@ def ssid(data: pd.Series, ratio_lim: float = 2.5, alpha1: float = 0.2, alpha2: f
     increasing the signal-to-noise ratio of a TS to SS situation.
 
     Args:
-        data (pandas.Series): Time series.
-        ratio_lim (float, optional): Threshold.
+        data: Time series.
+        ratio_lim: Threshold.
             Specifies the variance ratio threshold if it is in steady state or not. A variance ratio greater than the
             threshold labels the state as transient.
-        alpha1 (float, optional): Alpha 1.
+        alpha1: Alpha 1.
             Filter factor for the mean. Value should be between 0 and 1. Recommended value is 0.2.
             Defaults to 0.2.
-        alpha2 (float, optional): Alpha 2.
+        alpha2: Alpha 2.
             Filter factor for variance 1. Value should be between 0 and 1. Recommended value is 0.1.
             Defaults to 0.1.
-        alpha3 (float, optional): Alpha 3.
+        alpha3: Alpha 3.
             Filter factor for variance 2. Value should be between 0 and 1. Recommended value is 0.1.
             Defaults to 0.1.
 
@@ -192,8 +192,8 @@ def vma(series: pd.Series, window_length: int = 10) -> pd.Series:
     the variability of the signal in a lookup window.
 
     Args:
-        series (pandas.Series): Time series.
-        window_length (int, optional): Lookup window.
+        series: Time series.
+        window_length: Lookup window.
             Window length in data points used to estimate the variability of the signal.
 
     Returns:
