@@ -24,8 +24,8 @@ def holt_winters_predictor(
 ) -> pd.Series:
     """Triple exponential smoothing
 
-    This technique (also known by Holt-Winters) can be used to forecast time series data which displays a trend and a
-    seasonality.
+    This technique (also known by Holt-Winters) can be used to forecast time series data with a trend and
+    seasonal variability.
     It works by utilizing exponential smoothing thrice - for the average value, the trend and the seasonality.
     Values are predicted by combining the effects of these influences.
 
@@ -66,8 +66,8 @@ def holt_winters_predictor(
 
     validate_series_has_time_index(data)
 
-    if seasonal_periods <= 0:
-        raise UserValueError(f"seasonal_periods must be an integer > 0. Got {seasonal_periods}")
+    if seasonal_periods <= 1:
+        raise UserValueError(f"seasonal_periods must be an integer greater than 1. Got {seasonal_periods}")
 
     if not 0 < train_fraction < 1:
         raise UserValueError(f"train_fraction needs to be a float between 0 and 1. Got {train_fraction}")
