@@ -17,10 +17,10 @@ def productivity_index(p_res: pd.Series, p_bh: pd.Series, Q_gas: pd.Series, alig
     timestamp, then it will be ignored.
 
     Args:
-        p_res (pandas.Series): Reservoir pressure.
-        p_bh (pandas.Series): Bottomhole pressure.
-        Q_gas (pandas.Series): Gas flowrate.
-        align_timesteps (bool): Auto-align
+        p_res: Reservoir pressure.
+        p_bh: Bottomhole pressure.
+        Q_gas: Gas flowrate.
+        align_timesteps: Auto-align
           Automatically align time stamp  of input time series. Default is False.
 
     Returns:
