@@ -49,8 +49,6 @@ def poly_regression(
         fitter = Ridge(alpha=alpha)
     elif method == "Lasso":
         fitter = Lasso(alpha=alpha)
-    else:
-        raise UserValueError("Method needs to be either Ridge or Lasso.")
 
     model = make_pipeline(PolynomialFeatures(order), fitter)
 
