@@ -539,34 +539,3 @@ def _random_list_of_integers_that_gives_exact_sum(list_length: int, sum_output:
         int_list[rng.integers(0, sum_output) % list_length] += 1
 
     return int_list
-
-
-# TODO: add soliton synthetic time series
-def soliton():
-    # tsunami_wave
-    pass
-
-
-# TODO: add method chirp synthetic time series (see scipy https://docs.scipy.org/doc/scipy/reference/generated/scipy.signal.chirp.html)
-def chirp():
-    pass
-
-
-# TODO: Add gaussina pulse synthetic time series (https://docs.scipy.org/doc/scipy/reference/generated/scipy.signal.gausspulse.html)
-def gauss_pulse():
-    pass
-
-
-# TODO: Add method for sawtooth synthetic time series (https://docs.scipy.org/doc/scipy/reference/generated/scipy.signal.sawtooth.html)
-def sawtooth():
-    pass
-
-
-# TODO: Add method for ramp down / rap up synthetic time series.
-def ramp():
-    pass
-
-
-# TODO: add method step signal (single or multiple steps)
-def step():
-    pass
