@@ -37,19 +37,3 @@ def white_noise(
     white_noise = np.sqrt(noise_power) * rng.standard_normal(len(data))
 
     return data + white_noise
-
-
-def red():
-    pass
-
-
-def pink():
-    pass
-
-
-def purple():
-    pass
-
-
-def grey():
-    pass
