@@ -17,8 +17,8 @@ def univariate_polynomial(signal: pd.Series, coefficients: List[float] = [0.0, 1
         y = a_0 + a_1x + a_2x^2 + a_3x^3 + ... + a_nx^n
 
     Args:
-        signal (pandas.Series): Time series
-        coefficients (List[float]): Coefficients
+        signal: Time series
+        coefficients: Coefficients
             List of coefficient separated by commas. The numbers must be entered deparated by semicolons (e.g. 0; 1).
             The default is :math:`0.0; 1.0`, which returns the original time series.
 
