@@ -17,10 +17,10 @@ def arma(data: pd.Series, ar_order: int = 2, ma_order: int = 2):
 
 
     Args:
-        data (pandas.Series): Time series.
-        ar_order (int, optional): AR order.
+        data: Time series.
+        ar_order: AR order.
             Number of past dat points to include in the AR model. Defaults to 2.
-        ma_order (int, optional): MA order.
+        ma_order: MA order.
             Number of terms in the MA model.  Defaults to 2.
 
     Returns:
