@@ -1,5 +1,4 @@
 # Copyright 2021 Cognite AS
-import warnings
 
 import pandas as pd
 
@@ -54,10 +53,6 @@ def chebyshev(
     if filter_type not in {1, 2}:
         raise UserValueError("Filter type must be either 1 or 2.")
 
-    # Warn user if there are any missing values
-    if data.isna().any(axis=None):
-        warnings.warn("There are missing values present in the time series.", RuntimeWarning)
-
     # Get type 1 and 2 chebyshev filter
     cheby_filters = {1: cheby1, 2: cheby2}
 
