@@ -27,25 +27,25 @@ def ewma(
     yt=(xt+(1−α)*xt−1+(1−α)^2*xt−2+...+(1−α)^t*x0) / (1+(1−α)+(1−α)^2+...+(1−α)^t) if adjust = True.
 
     Args:
-        data (pandas.Series): Time series.
+        data: Time series.
             Data with a pd.DatetimeIndex.
-        time_window (str, optional): Time window.
+        time_window: Time window.
             Defines how important the current observation is in the calculation of the EWMA. The longer the period, the slowly it adjusts to reflect current trends. Defaults to '60min'.
             If the user gives a number without unit (such as '60'), it will be considered as the number of minutes.
             Accepted string format: '3w', '10d', '5h', '30min', '10s'.
             The time window is converted to the number of points for each of the windows. Each time window may have different number of points if the timeseries is not regular.
             The number of points specify the decay of the exponential weights in terms of span α=2/(span+1), for span≥1.
-        min_periods (int, optional): Minimum number of data points.
+        min_periods: Minimum number of data points.
             Minimum number of data points inside a time window required to have a value (otherwise result is NA). Defaults to 1.
             If min_periods > 1 and adjust is False, the SMA is computed for the first observation.
-        adjust (bool, optional): Adjust.
+        adjust: Adjust.
             If true, the exponential function is calculated using weights w_i=(1−α)^i.
             If false, the exponential function is calculated recursively using yt=(1−α)yt−1+αxt. Defaults to True.
-        max_pt (int, optional): Maximum number of data points.
+        max_pt: Maximum number of data points.
             Sets the maximum number of points to consider in a window if adjust = True. A high number of points will require more time to execute. Defaults to 200.
-        resample (bool, optional): Resample.
+        resample: Resample.
             If true, resamples the calculated exponential moving average series. Defaults to False.
-        resample_window (str, optional): Resampling window
+        resample_window: Resampling window
             Time window used to resample the calculated exponential moving average series. Defaults to '60min'.
 
     Returns:
