@@ -32,6 +32,12 @@ def sg(data: pd.Series, window_length: int = None, polyorder: int = 1) -> pd.Ser
 
     Returns:
         pandas.Series: Smoothed time series.
+
+    Raises:
+        UserValueError: The window length must be a positive odd integer
+        UserValueError: The window length must be less than or equal to the number of data points in your time series
+        UserValueError: The polynomial order must be less than the window length
+
     """
     if window_length is None:
         # window_length calculation
@@ -41,11 +47,11 @@ def sg(data: pd.Series, window_length: int = None, polyorder: int = 1) -> pd.Ser
     if window_length % 2 == 0:
         window_length += 1  # The filter requires the window to be odd
     if window_length <= 0:
-        raise UserValueError("The window length must be a positive odd integer")
+        raise UserValueError("The window length must be a positive odd integer.")
     if window_length > len(data):
         raise UserValueError(
-            "The window length must be less than or equal to the number of data points in your time series"
+            "The window length must be less than or equal to the number of data points in your time series."
         )
     if polyorder >= window_length:
-        raise UserValueError("The polynomial order must be less than the window length")
+        raise UserValueError("The polynomial order must be less than the window length.")
     return pd.Series(savgol_filter(data, window_length=window_length, polyorder=polyorder), index=data.index)
