@@ -36,11 +36,11 @@ def remove_outliers(
       high residuals (3 Standard Deviations from the Mean) are considered as outliers.
 
     Args:
-        data (pandas.Series): Time series.
-        reg_smooth (float, optional): Smoothing factor.
+        data: Time series.
+        reg_smooth: Smoothing factor.
             The smoothing parameter that determines the weighted sum of terms in the regression and it is limited by
             the range [0,1]. Defaults to 0.9. Ref: https://csaps.readthedocs.io/en/latest/formulation.html#definition
-        min_samples (int, optional): Minimum samples.
+        min_samples: Minimum samples.
             Minimum number of data points required to form a distinct cluster. Defaults to 4.
             Defines the minimum number of data points required to form a distinct cluster. Rules of thumb for selecting
             the minimum samples value:
@@ -52,7 +52,7 @@ def remove_outliers(
             * If your data has more than 2 dimensions, choose MinPts = 2*dim, where dim= the dimensions of your data
               set (Sander et al., 1998).
 
-        eps (float, optional): Distance threshold.
+        eps: Distance threshold.
             Defaults to None.  Defines the maximum distance between two samples for one to be considered as in the
             neighborhood of the other (i.e. belonging to the same cluster). The value of this parameter is automatically
             set after using a Nearest Neighbors algorithm to calculate the average distance between each point and its k
@@ -62,12 +62,12 @@ def remove_outliers(
             points within a cluster. This is the most important DBSCAN parameter to choose appropriately for your data
             set and distance function. If no value is given, it is set automatically using nearest neighbors algorithm.
             Defaults to None.
-        time_window (str, optional): Window.
+        time_window: Window.
             Length of the time period to compute the rolling mean. The rolling mean and the data point value are the two features considered when calculating the distance to the furthest neighbour.
             This distance allows us to find the right epsilon when training dbscan. Defaults to '60min'.
             Accepted string format: '3w', '10d', '5h', '30min', '10s'.
             If a number without unit (such as '60')is given, it will be considered as the number of minutes.
-        del_zero_val (bool, optional): Remove zeros.
+        del_zero_val: Remove zeros.
             Removes data points containing a value of 0. Defaults to False.
 
     Returns:
