@@ -23,10 +23,10 @@ def trapezoidal_integration(series: pd.Series, granularity: str = "1h", time_uni
     Cumulative integration using trapezoidal rule with an optional user-defined time unit.
 
     Args:
-        series (pandas.Series): Time series.
-        granularity (str): Granularity.
+        series: Time series.
+        granularity: Granularity.
             Current granularity for the chart on-screen (auto-given).
-        time_unit (str, optional): Frequency.
+        time_unit: Frequency.
             User defined granularity to potentially override unit of time.
             Accepts integer followed by time unit string (s|m|h|d). For example: '1s', '5m', '3h' or '1d'.
 
@@ -48,10 +48,10 @@ def differentiate(series: pd.Series, granularity: str = "1h", time_unit: str = "
     Boundary points are computed using a first-order accurate method.
 
     Args:
-        series (pandas.Series): Time series.
-        granularity (str): Granularity.
+        series: Time series.
+        granularity: Granularity.
             Current granularity for the chart on-screen (auto-given).
-        time_unit (str, optional): Frequency.
+        time_unit: Frequency.
             User defined granularity to potentially override unit of time.
             Accepts integer followed by time unit string (s|m|h|d). For example: '1s', '5m', '3h' or '1d'.
 
@@ -100,10 +100,10 @@ def integrate_windows(
     Since all the from and to window indexes are available and all inputs are np.ndarrays this is parallelized and sped up with numba.
 
     Args:
-        values (np.ndarray): Values to integrate corrected to the integrand rate.
-        dt (np.ndarray): The time in milliseconds between datapoints.
-        from_to_index (np.ndarray): index is the start of a window and value is the end index of the window.
-        number_of_windws(int): the number of windows to integrate
+        values: Values to integrate corrected to the integrand rate.
+        dt: The time in milliseconds between datapoints.
+        from_to_index: index is the start of a window and value is the end index of the window.
+        number_of_windows: the number of windows to integrate
 
     Returns:
         numpy.ndarray: The result of each integrated window.
@@ -128,8 +128,8 @@ def sliding_window_integration(
     Siding window integration using trapezoidal rule.
 
     Args:
-        series (pandas.Series): Time series.
-        window_length (pandas.Timedelta): window_length
+        series: Time series.
+        window_length: window_length
             the length of time the window. Defaults to '5 minute'. Valid time units are:
 
                 * ‘W’, ‘D’, ‘T’, ‘S’, ‘L’, ‘U’, or ‘N’
@@ -140,7 +140,7 @@ def sliding_window_integration(
                 * ‘milliseconds’, ‘millisecond’, ‘millis’, or ‘milli’
                 * ‘microseconds’, ‘microsecond’, ‘micros’, or ‘micro’
                 * ‘nanoseconds’, ‘nanosecond’, ‘nanos’, ‘nano’, or ‘ns’.
-        integrand_rate (pandas.Timedelta): integrand_rate.
+        integrand_rate: integrand_rate.
             if the integrands rate is per sec, per hour, per day.
             Defaults to '1 hour'. Valid time units are:
 
