@@ -9,7 +9,9 @@ import numpy as np
 import pandas as pd
 import scipy.integrate
 
-from ..exceptions import UserValueError
+from indsl.type_check import check_types
+
+from ..exceptions import UserRuntimeError, UserValueError
 
 
 _unit_in_ms_without_week = {"s": 1000, "m": 60000, "h": 3600000, "d": 86400000}
@@ -138,7 +140,7 @@ def functional_mean(function: Callable, x_vals: List) -> np.ndarray:
 
     # Catch empty input
     if len(x_vals) == 0:
-        raise RuntimeError("No data in the input timeseries.")
+        raise UserValueError("No data in the input timeseries.")
 
     y_vals = np.zeros(len(x_vals))
     for i in range(len(x_vals) - 1):
@@ -276,44 +278,70 @@ def fill_gaps(
     """Mask nan/fill gaps bases on the time size of missing data
 
     Args:
-        data: Time series to impute.
-        granularity: Temporal resolution of uniform time series, before resampling. Defaults to None.
+        data: Input time series. Must be uniform.
+        granularity: Temporal resolution of uniform time series, before resampling. Defaults to None. If not given as input, it will be inferred from the data.
         ffill_resolution: Gaps smaller than this will be filled with method. Defaults to None.
         interpolate_resolution: Gaps smaller than this will be interpolated, larger than this will be filled by noise. Defaults to None.
         method: Method used to fill nan. Defaults to 'ffill', but ‘backfill’, ‘bfill’ and ‘pad’ can also be used.
     Returns:
         pandas.DataFrame or pd.Series: Uniform, time series without nan values.
+    Raises:
+        UserRuntimeError: The input time series is not uniform
+        UserValueError: Unable to convert granularity to time resolution
+        UserValueError: granularity can not be 0
+        UserValueError: Unable to convert ffill_resolution to time resolution
+        UserValueError: ffill_resolution can not be 0
+        UserValueError: Unable to convert interpolate_resolution to time resolution
+        UserValueError: interpolate_resolution can not be 0
     """
+    if not check_uniform(data):
+        raise UserRuntimeError("The input time series is not uniform")
 
-    if not data.isnull().any():
+    if not data.isnull().values.any():
         # no need to proceed
         return data
 
     if method not in ("backfill", "bfill", "pad", "ffill"):
-        warnings.warn("Method should be in ('backfill', 'bfill', 'pad', 'ffill'). Set to ffill.", RuntimeWarning)
+        warnings.warn("Method should be in ('backfill', 'bfill', 'pad', 'ffill'). Set to ffill.")
         method = "ffill"
 
-    granularity_timedelata = pd.Timedelta("0T")
-    try:
-        granularity_timedelata = pd.Timedelta(granularity)
-    except ValueError:
-        raise UserValueError(f"Unable to convert {granularity} to time resolution", RuntimeWarning)
-
-    small_gap = 0
-    if ffill_resolution:
+    if granularity is not None:
         try:
-            small_gap = granularity_timedelata / pd.Timedelta(ffill_resolution)
-        except (ValueError, ZeroDivisionError):
-            raise UserValueError(f"Unable to convert {ffill_resolution} to time resolution", RuntimeWarning)
+            granularity_timedelta = pd.Timedelta(granularity)
+        except ValueError:
+            raise UserValueError(f"Unable to convert {granularity} to time resolution")
+    else:
+        # If granularity is not given as input. Granularity will be inferred from the data
+        granularity_timedelta = pd.Timedelta(data.index.inferred_freq)
+    if granularity_timedelta == pd.Timedelta("0T"):
+        raise UserValueError("granularity can not be 0")
+
+    if ffill_resolution is not None:
+        try:
+            ffill_resolution_timedelta = pd.Timedelta(ffill_resolution)
+        except ValueError:
+            raise UserValueError(f"Unable to convert {ffill_resolution} to time resolution")
+        if ffill_resolution_timedelta == pd.Timedelta("0T"):
+            raise UserValueError("ffill_resolution can not be 0")
 
-    inter_gap = None
-    mask_gap = 0
     if interpolate_resolution is not None:
         try:
-            mask_gap = granularity_timedelata / pd.Timedelta(interpolate_resolution)
-            inter_gap = int(mask_gap)
-        except (ValueError, ZeroDivisionError):
-            raise UserValueError(f"Unable to convert {interpolate_resolution} to time resolution", RuntimeWarning)
+            interpolate_resolution_timedelta = pd.Timedelta(interpolate_resolution)
+        except ValueError:
+            raise UserValueError(f"Unable to convert {interpolate_resolution} to time resolution")
+        if interpolate_resolution_timedelta == pd.Timedelta("0T"):
+            raise UserValueError("interpolate_resolution can not be 0")
+
+    small_gap = 0
+    inter_gap = None
+    mask_gap = 0
+
+    if ffill_resolution:
+        small_gap = granularity_timedelta / ffill_resolution_timedelta
+    if interpolate_resolution is not None:
+        mask_gap = granularity_timedelta / interpolate_resolution_timedelta
+        # inter_gap has to be above 0, but can be None
+        inter_gap = max(1, int(mask_gap))
 
     # ffill all, after interpolate and adding noise
     # create groups based on size of gap
@@ -340,6 +368,7 @@ def number_of_events(out: pd.Series):
     return len(np.where(out.values == 1)[0]) / 2
 
 
+@check_types
 def scalar_to_pandas_series(data: Union[float, pd.Series]) -> pd.Series:
     """Convert data to series if it is not already.
 
