@@ -1,4 +1,4 @@
-# Copyright 2021 Cognite AS
+# Copyright 2022 Cognite AS
 from collections import defaultdict
 from typing import Any, Callable, DefaultDict, Dict, List, Optional, Sequence
 
@@ -40,11 +40,8 @@ def register(
 
             The following are examples of invalid version numbers:
 
-                1
-                2.7.2.2
-                1.3.a4
                 1.3pl1
-                1.3c4
+                a
         name: Name of the function
             The name under which the function should be registered. If no name
             is specified, the name of the funtion is used.
